@@ -155,23 +155,18 @@ def plot_results(data,nodes,elems,**argv):
             mag = [np.linalg.norm(value) for value in value['data']]
             data_rolled.update({idd:{'name':value['name'] + ' (mag)','data':mag,'units':value['units']}}); idd +=1
 
-       
-       tmp = {'elems':elems,'nodes':nodes,'variables':data_rolled}
-       text='Bulk: ' + str(round(argv['bulk'],2)) +' W/m/K<br>Fourier: '\
-                     +       str(round(argv['fourier'],2)) + ' W/m/K<br>BTE:' 
+       tmp = {'elems':elems,'nodes':nodes,'variables':data_rolled,'fourier':argv['fourier'],'bulk':argv['bulk']}
 
        if 'bte' in argv.keys():
-           text += '<br>Fourier: '+ str(round(d['bte'],2))+' W/m/K'
-       tmp['text'] = text
+           tmp['bte'] = argv['bulk']
 
 
        data = {argv.setdefault('name','output'):tmp}
-       save_data(argv.setdefault('name','sample'),data)
+       save_data(argv.setdefault('name','output'),data)
 
 
    # plotly.io.to_image(fig,format='png')
    #fig.write_image("test.png",scale=5)
-
    if argv.setdefault('show',True):
     if 'google.colab' in sys.modules:
      fig.show(renderer='colab')
